@@ -20,7 +20,7 @@
 
 #include "config.h"
 #include <qframe.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qwidget.h>
 
 #include "kwave/SignalWidget.h"
@@ -69,8 +69,8 @@ public:
     int loadFile(const KURL &url);
 
     /** @see SignalWidget::saveFile() */
-    inline int saveFile(const KURL &url, unsigned int bits, bool selection) {
-	return m_signal_widget.saveFile(url, bits, selection);
+    inline int saveFile(const KURL &url, bool selection) {
+	return m_signal_widget.saveFile(url, selection);
     };
 
     /**
@@ -95,9 +95,6 @@ public:
      */
     unsigned int tracks();
 
-    /** Returns the resolution in bits per sample */
-    unsigned int bits();
-
     /** Returns the signal manager of the current signal */
     SignalManager &signalManager();
 
@@ -166,7 +163,8 @@ private slots:
      * Forwards the selectedTimeInfo signal of the internal view window
      * by emitting selectedTimeInfo.
      */
-    void forwardSelectedTimeInfo(unsigned int samples, double ms);
+    void forwardSelectedTimeInfo(unsigned int offset, unsigned int length,
+                                 double rate);
 
     /**
      * Forwards the sigMouseChanged signal of the internal view window
@@ -210,10 +208,11 @@ signals:
     void sigZoomChanged(double zoom);
 
     /**
-     * Emits the length of the current selection in samples
-     * and in milliseconds
+     * Emits the offset and length of the current selection and the
+     * sample rate for converting it into milliseconds
      */
-    void selectedTimeInfo(unsigned int samples, double ms);
+    void selectedTimeInfo(unsigned int offset, unsigned int length,
+                          double rate);
 
     /** Emits the current number of tracks */
     void sigTrackCount(unsigned int tracks);
@@ -245,10 +244,10 @@ private:
     QScrollBar *m_scrollbar;
 
     /** array of lamps, one for each channel */
-    QList<MultiStateWidget> m_lamps;
+    QPtrList<MultiStateWidget> m_lamps;
 
 //    /** array of speaker icons, one for each channel */
-//    QList<MultiStateWidget> m_speakers;
+//    QPtrList<MultiStateWidget> m_speakers;
 
     /** the last number of channels (for detecting changes) */
     unsigned int m_last_tracks;
