@@ -29,7 +29,6 @@
 #include <klocale.h>
 
 #include "mt/SignalProxy.h"
-#include "mt/TSS_Object.h"
 #include "mt/ThreadCondition.h"
 
 #include "libkwave/ArtsMultiPlaybackSink.h"
@@ -172,7 +171,7 @@ void PluginManager::loadAllPlugins()
 	} else {
 	    // loading failed => remove it from the list
 	    qWarning("PluginManager::loadAllPlugins(): removing '%s' "\
-	            "from list", name.latin1());
+	            "from list", name.data());
 	    m_plugin_files.remove(name);
 	}
     }
@@ -188,8 +187,9 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
 	KwavePlugin *p = itp.current();
 	if (p->isPersistent() && (p->name() == name)) {
 	    Q_ASSERT(p->isPersistent());
-	    qDebug("PluginManager::loadPlugin('"+name+
-	           "') -> returning pointer to persistent");
+	    qDebug("PluginManager::loadPlugin('%s')"\
+	           "-> returning pointer to persistent",
+	           name.local8Bit().data());
 	    return p;
 	}
     }
@@ -201,8 +201,9 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
 	if (p->name() == name) {
 	    Q_ASSERT(p->isUnique());
 	    Q_ASSERT(p->isPersistent());
-	    qDebug("PluginManager::loadPlugin('"+name+
-	           "') -> returning pointer to unique+persistent");
+	    qDebug("PluginManager::loadPlugin('%s')"\
+	           "-> returning pointer to unique+persistent",
+	           name.local8Bit().data());
 	    return p;
 	}
     }
@@ -229,7 +230,7 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
     }
 
     // get the loader function
-    KwavePlugin *(*plugin_loader)(PluginContext *c) = 0;
+    KwavePlugin *(*plugin_loader)(const PluginContext *c) = 0;
 
     // hardcoded, should always work when the
     // symbols are declared as extern "C"
@@ -252,19 +253,20 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
     if (!version) version = i18n("(unknown)");
 
     plugin_loader =
-        (KwavePlugin *(*)(PluginContext *))dlsym(handle, sym_loader);
+        (KwavePlugin *(*)(const PluginContext *))dlsym(handle, sym_loader);
     Q_ASSERT(plugin_loader);
     if (!plugin_loader) {
 	// plugin is null, out of memory or not found
-	qWarning("PluginManager::loadPlugin('"+name+"'): "\
+	qWarning("PluginManager::loadPlugin('%s'): "\
 		"plugin does not contain a loader, "\
-		"maybe it is damaged or the wrong version?");
+		"maybe it is damaged or the wrong version?",
+		name.local8Bit().data());
 	dlclose(handle);
 	return 0;
     }
 
-    PluginContext *context = new PluginContext(
-    m_top_widget.getKwaveApp(),
+    PluginContext context(
+	m_top_widget.getKwaveApp(),
 	*this,
 	0, // LabelManager  *label_mgr,
 	0, // MenuManager   *menu_mgr,
@@ -275,18 +277,12 @@ KwavePlugin *PluginManager::loadPlugin(const QString &name)
 	author
     );
 
-    Q_ASSERT(context);
-    if (!context) {
-	qWarning("PluginManager::loadPlugin('"+name+"'): out of memory");
-	dlclose(handle);
-	return 0;
-    }
-
     // call the loader function to create an instance
-    KwavePlugin *plugin = (*plugin_loader)(context);
+    KwavePlugin *plugin = (*plugin_loader)(&context);
     Q_ASSERT(plugin);
     if (!plugin) {
-	qWarning("PluginManager::loadPlugin('"+name+"'): out of memory");
+	qWarning("PluginManager::loadPlugin('%s'): out of memory",
+	         name.local8Bit().data());
 	dlclose(handle);
 	return 0;
     }
@@ -372,7 +368,7 @@ int PluginManager::executePlugin(const QString &name, QStringList *params)
 	    }
 	    delete params;
 	    command += ")";
-	    qDebug("PluginManager: command='%s'",command.latin1()); // ###
+	    qDebug("PluginManager: command='%s'",command.data()); // ###
 	}
     }
 
@@ -398,7 +394,8 @@ void PluginManager::sync()
 	for (; it.current(); ++it) {
 	    KwavePlugin *plugin = it.current();
 	    if (plugin->isRunning()) {
-		qDebug("waiting for plugin '%s'", plugin->name().latin1());
+		qDebug("waiting for plugin '%s'",
+		       plugin->name().local8Bit().data());
 		one_is_running = true;
 		break;
 	    }
@@ -466,8 +463,8 @@ QStringList PluginManager::loadPluginDefaults(const QString &name,
     if (!(def_version == version)) {
 	qDebug("PluginManager::loadPluginDefaults: "\
 	    "plugin '%s': defaults for version '%s' not loaded, found "\
-	    "old ones of version '%s'.", name.latin1(), version.latin1(),
-	    def_version.latin1());
+	    "old ones of version '%s'.", name.local8Bit().data(),
+	    version.local8Bit().data(), def_version.local8Bit().data());
 	return list;
     }
 
@@ -777,7 +774,7 @@ void PluginManager::findPlugins()
 
 	    dlclose (handle);
 	} else {
-	    qWarning(i18n("error in '%s':\n\t %s"), file.latin1(),
+	    qWarning(i18n("error in '%s':\n\t %s"), file.data(),
 		dlerror());
 	}
     }
