@@ -20,9 +20,9 @@
 
 #include "config.h"
 #include <qobject.h>
-#include <qarray.h>
-#include <qlist.h>
-#include <qvector.h>
+#include <qmemarray.h>
+#include <qptrlist.h>
+#include <qptrvector.h>
 #include <qmap.h>
 
 #include <arts/artsflow.h>
@@ -30,13 +30,17 @@
 #include "mt/SignalProxy.h"
 #include "libkwave/InsertMode.h"
 
+class ArtsMultiSink;
+class FileInfo;
 class KwavePlugin;
 class PlaybackController;
+class PlaybackDeviceFactory;
 class QBitmap;
 class QString;
 class QStringList;
 class SampleWriter;
 class TopWidget;
+class UndoAction;
 class MultiTrackReader;
 class MultiTrackWriter;
 
@@ -81,6 +85,7 @@ public:
 
     /**
      * Executes a plugin in the context of a given parent widget.
+     * @return zero on success or negative error code
      */
     int executePlugin(const QString &name, QStringList *params);
 
@@ -96,6 +101,12 @@ public:
      */
     int setupPlugin(const QString &name);
 
+    /**
+     * Returns a reference to the FileInfo object associated with the
+     * currently opened file.
+     */
+    FileInfo &fileInfo();
+
     /**
      * Returns the length of the current signal in samples.
      * If no signal is present the return value will be 0.
@@ -106,12 +117,12 @@ public:
      * Returns the current sample rate in samples per second.
      * If no signal is present the return value will be 0.
      */
-    unsigned int signalRate();
+    double signalRate();
 
     /**
      * Returns an array of indices of currently selected channels.
      */
-    const QArray<unsigned int> selectedTracks();
+    const QMemArray<unsigned int> selectedTracks();
 
     /**
      * Returns the start of the selection. If nothing is currently
@@ -151,7 +162,7 @@ public:
      * @see selectedTracks()
      */
     void openMultiTrackReader(MultiTrackReader &readers,
-	const QArray<unsigned int> &track_list,
+	const QMemArray<unsigned int> &track_list,
 	unsigned int first, unsigned int last);
 
     /**
@@ -180,7 +191,7 @@ public:
      * @see InsertMode
      */
     void openMultiTrackWriter(MultiTrackWriter &writers,
-	const QArray<unsigned int> &track_list, InsertMode mode,
+	const QMemArray<unsigned int> &track_list, InsertMode mode,
 	unsigned int left, unsigned int right);
 
     /**
@@ -193,6 +204,16 @@ public:
     void openMultiTrackWriter(MultiTrackWriter &writers,
                               InsertMode mode);
 
+    /**
+     * Opens a set of SampleWriters for playback purposes.
+     * @param tracks number of tracks
+     * @param name of the device, optional. If not given, the default
+     *        playback device is used
+     * @return a multitrack aRts sink that receives the playback stream
+     */
+    ArtsMultiSink *openMultiTrackPlayback(unsigned int tracks,
+                                          const QString *name = 0);
+
     /**
      * Returns a reference to the current playback controller. This is
      * only needed for plugins doing playback.
@@ -218,6 +239,16 @@ public:
 	return Arts::Dispatcher::the();
     };
 
+    /**
+     * Registers a PlaybackDeviceFactory
+     */
+    void registerPlaybackDeviceFactory(PlaybackDeviceFactory *factory);
+
+    /**
+     * Unregisters a PlaybackDeviceFactory
+     */
+    void unregisterPlaybackDeviceFactory(PlaybackDeviceFactory *factory);
+    
 signals:
     /**
      * Forwards commands to the parent TopWidget execute a command
@@ -240,10 +271,8 @@ public slots:
     /**
      * Will be connected to the plugin's "closed" signal.
      * @param p pointer to the plugin to be closed
-     * @param remove if true, the plugin will also be deleted,
-     *        if false the plugin is expected to delete itself
      */
-    void pluginClosed(KwavePlugin *p, bool remove);
+    void pluginClosed(KwavePlugin *p);
 
     /**
      * Called if the name of the current signal has changed. This will be
@@ -263,8 +292,32 @@ private slots:
      */
     void forwardCommand();
 
+    /** called when a plugin has started (running) it's worker thread */
+    void pluginStarted(KwavePlugin *p);
+
+    /** called when a plugin has finished it's worker thread */
+    void pluginDone(KwavePlugin *p);
+
 private:
 
+    /**
+     * Helper class for deferred deleting and unloading a plugin
+     * @internal
+     */
+    class PluginDeleter: public QObject
+    {
+    public:
+        /** Constructor, stores data for later removal */
+	PluginDeleter(KwavePlugin *plugin, void *handle);
+	
+	/** Destructor, deletes and unloads the plugin */
+	virtual ~PluginDeleter();
+	
+    private:
+	KwavePlugin *m_plugin; /**< Plugin to be deleted */
+	void *m_handle;        /**< Handle of the shared object */
+    };
+
     /**
      * Uses the dynamic linker to load a plugin into memory.
      * @param name the name of the plugin (filename)
@@ -280,7 +333,7 @@ private:
      * the plugin does not match the version number in the config file,
      * the return value will also be 0.
      * @param name the name of the plugin
-     * @param var the version number of the plugin
+     * @param version the version number of the plugin
      * @return list of strings
      */
     QStringList loadPluginDefaults(const QString &name,
@@ -292,8 +345,8 @@ private:
      * before saving the new settings in order to wipe out invalid
      * entries and settings that belong to an older version.
      * @param name the name of the plugin
-     * @param ver the version number of the plugin
-     * @param param a list of configuration strings
+     * @param version the version number of the plugin
+     * @param params a list of configuration strings
      */
     void savePluginDefaults(const QString &name, const QString &version,
                             QStringList &params);
@@ -313,8 +366,14 @@ private:
     /** map for finding plugin files through their name */
     static QMap<QString, QString> m_plugin_files;
 
-    /** list of loaded plugins */
-    QList<KwavePlugin> m_loaded_plugins;
+    /** list of own loaded plugins */
+    QPtrList<KwavePlugin> m_loaded_plugins;
+
+    /** global list of loaded unique plugins */
+    static QPtrList<KwavePlugin> m_unique_plugins;
+
+    /** list of currently running plugins */
+    QPtrList<KwavePlugin> m_running_plugins;
 
     /** reference to our parent toplevel widget */
     TopWidget &m_top_widget;
