@@ -29,6 +29,7 @@
 #include <qstring.h>
 #include <qtimer.h>
 
+#include <kaboutdata.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kmimetype.h>
@@ -97,6 +98,10 @@ SignalManager::SignalManager(QWidget *parent)
     /** @todo the undo memory limit should be user-configurable. */
     m_file_info()
 {
+    // per default we use auto-delete for the und/redo buffers
+    m_undo_buffer.setAutoDelete(true);
+    m_redo_buffer.setAutoDelete(true);
+
     // connect to the track's signals
     Signal *sig = &m_signal;
     connect(sig, SIGNAL(sigTrackInserted(unsigned int, Track &)),
@@ -133,43 +138,48 @@ int SignalManager::loadFile(const KURL &url)
     disableUndo();
 
     QString mimetype = CodecManager::whatContains(url);
-    qDebug("SignalManager::loadFile(%s) - [%s]", url.prettyURL().latin1(),
-          mimetype.latin1());
+    qDebug("SignalManager::loadFile(%s) - [%s]",
+           url.prettyURL().local8Bit().data(),
+           mimetype.local8Bit().data());
     Decoder *decoder = CodecManager::decoder(mimetype);
     while (decoder) {
 	// be sure that the current signal is really closed
 	m_signal.close();
-	
+
 	// open the source file
 	QString filename = url.path();
 	QFile src(filename);
 	if (!(res = decoder->open(m_parent_widget, src))) {
-	    qWarning("unable to open source: '%s'", url.prettyURL().latin1());
+	    qWarning("unable to open source: '%s'",
+	             url.prettyURL().local8Bit().data());
+	    res = -EIO;
 	    break;
 	}
-	
+
 	// enter the filename/mimetype and size into the decoder
 	QFileInfo fi(src);
 	decoder->info().set(INF_FILENAME, fi.absFilePath());
 	decoder->info().set(INF_FILESIZE, (unsigned int)src.size());
 	decoder->info().set(INF_MIMETYPE, mimetype);
-	
+
 	// get the file info from the decoder
 	m_file_info = decoder->info();
-	
+
 	// detect stream mode. if so, use one sample as display
 	bool streaming = (!m_file_info.length());
-	
+
 	// we must change to open state to see the file while
 	// it is loaded
 	m_closed = false;
 	m_empty = false;
-	
+
 	// create all tracks (empty)
 	unsigned int track;
 	const unsigned int tracks = decoder->info().tracks();
 	const unsigned int length = decoder->info().length();
 	Q_ASSERT(tracks);
+	if (!tracks) break;
+
 	for (track=0; track < tracks; ++track) {
 	    Track *t = m_signal.appendTrack(length);
 	    Q_ASSERT(t);
@@ -180,7 +190,7 @@ int SignalManager::loadFile(const KURL &url)
 	    }
 	}
 	if (track < tracks) break;
-	
+
 	// create the multitrack writer as destination
 	MultiTrackWriter writers;
 
@@ -196,7 +206,7 @@ int SignalManager::loadFile(const KURL &url)
 	                              (info.bits() >> 3);
 	bool use_src_size = (!resulting_size);
 	if (use_src_size) resulting_size = src.size();
-	
+
 	//prepare and show the progress dialog
 	dialog = new FileProgress(m_parent_widget,
 	    filename, resulting_size,
@@ -215,7 +225,7 @@ int SignalManager::loadFile(const KURL &url)
 	}
 	QObject::connect(dialog, SIGNAL(cancelled()),
 	                 &writers, SLOT(cancel()));
-	
+
 	// now decode
 	res = 0;
 	if (!decoder->decode(m_parent_widget, writers)) {
@@ -227,9 +237,9 @@ int SignalManager::loadFile(const KURL &url)
 	    m_file_info = decoder->info();
 	    m_file_info.dump();
 	}
-	
+
 	decoder->close();
-	
+
 	// check for length info in stream mode
 	if (!res && streaming) {
 	    // source was opened in stream mode -> now we have the length
@@ -237,14 +247,17 @@ int SignalManager::loadFile(const KURL &url)
 	    unsigned int new_length = writers.last();
 	    if (new_length) new_length++;
 	    m_file_info.setLength(new_length);
+	} else {
+	    m_file_info.setLength(this->length());
+	    m_file_info.setTracks(tracks);
 	}
-	
+
 	// update the length info in the progress dialog if needed
 	if (dialog && use_src_size) {
 	    dialog->setLength(m_file_info.length() * m_file_info.tracks());
 	    dialog->setBytePosition(src.size());
 	}
-	
+
 	emitStatusInfo();
 	break;
     }
@@ -266,7 +279,7 @@ int SignalManager::loadFile(const KURL &url)
 
     if (dialog) delete dialog;
     if (res) close();
-    
+
     return res;
 }
 
@@ -295,13 +308,14 @@ int SignalManager::save(const KURL &url, bool selection)
     QString mimetype_name;
     mimetype_name = CodecManager::whatContains(url);
     qDebug("SignalManager::save(%s) - [%s] (%d bit, selection=%d)",
-	url.prettyURL().latin1(), mimetype_name.latin1(), bits, selection);
+	url.prettyURL().local8Bit().data(), mimetype_name.data(),
+	bits, selection);
 
     Encoder *encoder = CodecManager::encoder(mimetype_name);
     if (encoder) {
 	// maybe we now have a new mime type
 	m_file_info.set(INF_MIMETYPE, mimetype_name);
-    
+
 	// check if we loose information and as the user if this would
 	// be acceptable if so
 	QValueList<FileProperty> supported = encoder->supportedProperties();
@@ -314,7 +328,7 @@ int SignalManager::save(const KURL &url, bool selection)
                  (m_file_info.canLoadSave(it.key())) )
 	    {
 		qWarning("SignalManager::save(): unsupported property '%s'",
-		    m_file_info.name(it.key()).latin1());
+		    m_file_info.name(it.key()).data());
 		all_supported = false;
 		lost_properties += m_file_info.name(it.key()) + "\n";
 	    }
@@ -327,27 +341,59 @@ int SignalManager::save(const KURL &url, bool selection)
 		     "%1\n"
 		     "Do you still want to continue?").arg(
 		     lost_properties)
-		) != KMessageBox::Continue) return -1;
+		) != KMessageBox::Continue)
+	    {
+		delete encoder;
+		return -1;
+	    }
 	}
 
 	// open the destination file
 	QString filename = url.path();
 	QFile dst(filename);
-	
+
 	MultiTrackReader src;
 	if (selection) {
 	    openMultiTrackReader(src, selectedTracks(), ofs, ofs+len-1);
 	} else {
 	    openMultiTrackReader(src, allTracks(), ofs, ofs+len-1);
 	}
-	
+
 	// update the file information
 	m_file_info.setLength(len);
 	m_file_info.setRate(rate());
 	m_file_info.setBits(bits);
 	m_file_info.setTracks(tracks);
 	m_file_info.set(INF_FILENAME, filename);
-	
+
+	if (!m_file_info.contains(INF_SOFTWARE) &&
+	    encoder->supportedProperties().contains(INF_SOFTWARE))
+	{
+	    // add our Kwave Software tag
+	    const KAboutData *about_data = KGlobal::instance()->aboutData();
+	    QString software = about_data->programName() + "-" +
+	                       about_data->version() +
+	                       i18n(" for KDE ") +
+			       i18n(QString::fromLatin1(KDE_VERSION_STRING));
+	    qDebug("adding software tag: '%s'",
+	           software.local8Bit().data());
+	    m_file_info.set(INF_SOFTWARE, software);
+	}
+
+	if (!m_file_info.contains(INF_CREATION_DATE) &&
+	    encoder->supportedProperties().contains(INF_CREATION_DATE))
+	{
+	    // add a date tag
+	    QDate now(QDate::currentDate());
+	    QString date;
+	    date = date.sprintf("%04d-%02d-%02d",
+	    now.year(), now.month(), now.day());
+	    QVariant value = date.utf8();
+	    qDebug("adding date tag: '%s'",
+	           date.local8Bit().data());
+	    m_file_info.set(INF_CREATION_DATE, value);
+	}
+
 	//prepare and show the progress dialog
 	FileProgress *dialog = new FileProgress(m_parent_widget,
 	    filename, m_file_info.tracks()*m_file_info.length()*
@@ -359,14 +405,14 @@ int SignalManager::save(const KURL &url, bool selection)
 	                 dialog, SLOT(setValue(unsigned int)));
 	QObject::connect(dialog, SIGNAL(cancelled()),
 	                 &src,   SLOT(cancel()));
-	
+
 	// invoke the encoder...
 	if (!encoder->encode(m_parent_widget, src, dst, m_file_info)) {
 	    KMessageBox::error(m_parent_widget,
 	        i18n("An error occurred while saving the file!"));
 	    res = -1;
 	}
-	
+
 	delete encoder;
 	if (dialog) {
 	    if (dialog->isCancelled()) {
@@ -414,10 +460,12 @@ void SignalManager::newSignal(unsigned int samples, double rate,
     m_empty = false;
 
     // add all empty tracks
+    m_file_info.setTracks(tracks);
     while (tracks--) m_signal.appendTrack(samples);
 
     // remember the last length
     m_last_length = samples;
+    m_file_info.setLength(length());
 
     // from now on, undo is enabled
     enableUndo();
@@ -438,6 +486,10 @@ void SignalManager::close()
     // undo will be re-enabled when a signal is loaded or created
     disableUndo();
 
+    // for safety: flush all undo/redo buffer
+    flushUndoBuffers();
+    flushRedoBuffer();
+
     m_empty = true;
     m_name = "";
     while (tracks()) deleteTrack(tracks()-1);
@@ -496,7 +548,8 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
     UndoAction *action = 0;
     switch (mode) {
 	case Append:
-	    qDebug("SignalManager::openSampleWriter(): NO UNDO FOR APPEND YET !");
+	    qDebug("SignalManager::openSampleWriter(): "\
+	           "NO UNDO FOR APPEND YET !");
 	    break;
 	case Insert:
 	    action = new UndoInsertAction(track, left, right-left+1);
@@ -512,7 +565,7 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
     }
     Q_ASSERT(action);
 
-    {
+    if (m_undo_enabled) {
 	ThreadsafeX11Guard x11_guard;
 	if (!registerUndoAction(action)) {
 	    // creating/starting the action failed, so fail now.
@@ -571,8 +624,6 @@ void SignalManager::openMultiTrackWriter(MultiTrackWriter &writers,
 //***************************************************************************
 bool SignalManager::executeCommand(const QString &command)
 {
-//    qDebug("SignalManager::executeCommand(%s)", command.latin1());    // ###
-
     unsigned int offset = m_selection.offset();
     unsigned int length = m_selection.length();
     double rate = m_file_info.rate();
@@ -675,7 +726,7 @@ void SignalManager::paste(ClipBoard &clipboard, unsigned int offset,
     if (!tracks()) {
 	unsigned int missing = clipboard.tracks();
 	qDebug("SignalManager::paste(): appending %u tracks", missing);
-	while (missing--) appendTrack();	
+	while (missing--) appendTrack();
     }
 
     // open the clipboard as source
@@ -714,11 +765,13 @@ void SignalManager::insertTrack(unsigned int index)
 {
     UndoTransactionGuard u(*this, i18n("insert track"));
 
-    UndoAction *undo = new UndoInsertTrack(m_signal, index);
-    if (!registerUndoAction(undo)) {
-	if (undo) delete undo;
-	abortUndoTransaction();
-	return;
+    if (m_undo_enabled) {
+	UndoAction *undo = new UndoInsertTrack(m_signal, index);
+	if (!registerUndoAction(undo)) {
+	    if (undo) delete undo;
+	    abortUndoTransaction();
+	    return;
+	}
     }
 
     unsigned int count = tracks();
@@ -748,11 +801,13 @@ void SignalManager::deleteTrack(unsigned int index)
 {
     UndoTransactionGuard u(*this, i18n("delete track"));
 
-    UndoAction *undo = new UndoDeleteTrack(m_signal, index);
-    if (!registerUndoAction(undo)) {
-	if (undo) delete undo;
-	abortUndoTransaction();
-	return;
+    if (m_undo_enabled) {
+	UndoAction *undo = new UndoDeleteTrack(m_signal, index);
+	if (!registerUndoAction(undo)) {
+	    if (undo) delete undo;
+	    abortUndoTransaction();
+	    return;
+	}
     }
 
     setModified(true);
@@ -837,14 +892,17 @@ bool SignalManager::deleteRange(unsigned int offset, unsigned int length,
     // first store undo data for all tracks
     unsigned int track;
     unsigned int i;
-    for (i=0; i < count; i++) {
-	track = track_list[i];
-	UndoAction *undo = new UndoDeleteAction(track, offset, length);
-	if (!registerUndoAction(undo)) {
-	    // abort
-	    if (undo) delete undo;
-	    abortUndoTransaction();
-	    return false;
+
+    if (m_undo_enabled) {
+	for (i=0; i < count; i++) {
+	    track = track_list[i];
+	    UndoAction *undo = new UndoDeleteAction(track, offset, length);
+	    if (!registerUndoAction(undo)) {
+		// abort
+		if (undo) delete undo;
+		abortUndoTransaction();
+		return false;
+	    }
 	}
     }
 
@@ -900,7 +958,7 @@ void SignalManager::selectTrack(unsigned int track, bool select)
     if (select != old_select) {
 	m_signal.selectTrack(track, select);
 	emit sigTrackSelected(track, select);
-	
+
 	// if selection changed during playback, reload with pause/continue
 	if (m_playback_controller.running()) {
 	    m_playback_controller.reload();
@@ -919,7 +977,7 @@ int SignalManager::loadAscii()
     float amp;
     int *sample = 0;
 
-    FILE *sigin = fopen(m_name.latin1(), "r");
+    FILE *sigin = fopen(m_name.local8Bit(), "r");
     if (!sigin) {
 	KMessageBox::error(0, i18n("File does not exist !"), i18n("Info"), 2);
 	return -ENOENT;
@@ -1021,7 +1079,7 @@ int SignalManager::exportAscii(const char *name)
 	for (unsigned int channel=0; channel < m_channels; channel++) {
 	    sample = signal.at(channel)->getSample();
 	    if (!sample) continue;
-	
+
 	    if (channel != 0) fprintf(sigout, ",");
 	    fprintf(sigout, "%0.8e", (double)sample[pos]/scale_y);
 	}
@@ -1064,11 +1122,11 @@ void SignalManager::startUndoTransaction(const QString &name)
     if (!m_undo_transaction) {
 	// if a new action starts, discard all redo actions !
 	flushRedoBuffer();
-	
+
 	m_undo_transaction = new UndoTransaction(name);
 	Q_ASSERT(m_undo_transaction);
 	if (!m_undo_transaction) return;
-	
+
 	// if it is the start of the transaction, also create one
 	// for the selection
 	UndoAction *selection = new UndoSelection(*this);
@@ -1100,7 +1158,7 @@ void SignalManager::closeUndoTransaction()
 		delete m_undo_transaction;
 	    }
 	}
-	
+
 	// declare the current transaction as "closed"
 	m_undo_transaction = 0;
 	m_spx_undo_redo.AsyncHandler();
@@ -1119,8 +1177,8 @@ void SignalManager::disableUndo()
 {
     Q_ASSERT(m_undo_transaction_level == 0);
 
-    m_undo_enabled = false;
     flushUndoBuffers();
+    m_undo_enabled = false;
 }
 
 //***************************************************************************
@@ -1154,9 +1212,6 @@ void SignalManager::abortUndoTransaction()
     MutexGuard lock(m_undo_transaction_lock);
 
     if (!m_undo_transaction) return;
-    m_undo_transaction->setAutoDelete(true);
-    m_undo_transaction->clear();
-
     delete m_undo_transaction;
     m_undo_transaction = 0;
 }
@@ -1175,8 +1230,9 @@ bool SignalManager::registerUndoAction(UndoAction *action)
     Q_ASSERT(action);
     if (!action) return false;
 
-    // if undo is not enabled, return a faked "ok"
-    if (!m_undo_enabled) return true;
+    // if undo is not enabled, this will fail -> no memory leak!
+    Q_ASSERT(m_undo_enabled);
+    if (!m_undo_enabled) return false;
 
     unsigned int needed_size  = action->undoSize();
     unsigned int needed_mb = needed_size  >> 20;
@@ -1186,17 +1242,17 @@ bool SignalManager::registerUndoAction(UndoAction *action)
 	// Allow: discard buffers and omit undo
 	m_undo_buffer.clear();
 	m_redo_buffer.clear();
-	
+
 	// close the current transaction
 	if (m_undo_transaction) delete m_undo_transaction;
 	m_undo_transaction = 0;
-	
+
 	// if the signal was modified, it will stay in this state, it is
 	// not possible to change to "non-modified" state through undo
 	if ((!m_undo_buffer.isEmpty()) && (m_modified)) {
 	    enableModifiedChange(false);
 	}
-	
+
 	m_spx_undo_redo.AsyncHandler();
 	return true;
     }
@@ -1227,7 +1283,7 @@ bool SignalManager::saveUndoDelete(QMemArray<unsigned int> &track_list,
     undo_list.setAutoDelete(true);
 
     // loop over all tracks
-    while (count--) {
+    while (m_undo_enabled && count--) {
 	unsigned int t = track_list[count];
 	UndoDeleteAction *action = new UndoDeleteAction(t, offset, length);
 	if (!registerUndoAction(action)) {
@@ -1266,7 +1322,6 @@ void SignalManager::freeUndoMemory(unsigned int needed)
     unsigned int size = usedUndoRedoMemory() + needed;
 
     // remove old undo actions if not enough free memory
-    m_undo_buffer.setAutoDelete(true);
     while (!m_undo_buffer.isEmpty() && (size > m_undo_limit)) {
 	unsigned int s = m_undo_buffer.first()->undoSize();
 	size = (size >= s) ? (size - s) : 0;
@@ -1280,7 +1335,6 @@ void SignalManager::freeUndoMemory(unsigned int needed)
     }
 
     // remove old redo actions if still not enough memory
-    m_redo_buffer.setAutoDelete(true);
     while (!m_redo_buffer.isEmpty() && (size > m_undo_limit)) {
 	unsigned int s = m_redo_buffer.last()->undoSize();
 	size = (size >= s) ? (size - s) : 0;
@@ -1298,14 +1352,14 @@ void SignalManager::emitUndoRedoInfo()
 
     if (m_undo_enabled) {
 	UndoTransaction *transaction;
-	
+
 	// get the description of the last undo action
 	if (!m_undo_buffer.isEmpty()) {
 	    transaction = m_undo_buffer.last();
 	    if (transaction) undo_name = transaction->description();
 	    if (!undo_name.length()) undo_name = i18n("last action");
 	}
-	
+
 	// get the description of the last redo action
 	if (!m_redo_buffer.isEmpty()) {
 	    transaction = m_redo_buffer.first();
@@ -1348,7 +1402,7 @@ void SignalManager::undo()
     } else {
 	// only free the memory if it will be used
 	freeUndoMemory(undo_size + redo_size);
-	
+
 	// create a new redo transaction
 	QString name = undo_transaction->description();
 	redo_transaction = new UndoTransaction(name);
@@ -1369,22 +1423,23 @@ void SignalManager::undo()
     while (!undo_transaction->isEmpty()) {
 	UndoAction *undo_action;
 	UndoAction *redo_action;
-	
+
 	// unqueue the undo action
-	undo_transaction->setAutoDelete(false);
 	undo_action = undo_transaction->last();
+	undo_transaction->setAutoDelete(false);
 	undo_transaction->removeLast();
+	undo_transaction->setAutoDelete(true);
 	Q_ASSERT(undo_action);
 	if (!undo_action) continue;
-	
+
 	// execute the undo operation
 	redo_action = undo_action->undo(*this, (redo_transaction != 0));
-	
+
 	// remove the old undo action if no longer used
 	if (redo_action != undo_action) {
 	    delete undo_action;
 	}
-	
+
 	// queue the action into the redo transaction
 	if (redo_action) {
 	    if (redo_transaction) {
@@ -1396,11 +1451,14 @@ void SignalManager::undo()
 	}
     }
 
+    // now the undo_transaction should be empty -> get rid of it
+    Q_ASSERT(undo_transaction->isEmpty());
+    delete undo_transaction;
+
     if (redo_transaction && (redo_transaction->count() <= 1)) {
 	// if there is not more than the UndoSelection action,
 	// there are no real redo actions -> no redo possible
 	qWarning("SignalManager::undo(): no redo possible");
-	m_redo_buffer.setAutoDelete(true);
 	m_redo_buffer.remove(redo_transaction);
     }
 
@@ -1443,7 +1501,7 @@ void SignalManager::redo()
     } else {
 	// only free the memory if it will be used
 	freeUndoMemory(undo_size + redo_size);
-	
+
 	// create a new undo transaction
 	QString name = redo_transaction->description();
 	undo_transaction = new UndoTransaction(name);
@@ -1453,7 +1511,6 @@ void SignalManager::redo()
     // if *one* undo fails, all following undoes will also fail or
     // produce inconsistent data -> remove all of them !
     if (!undo_transaction) {
-	m_undo_buffer.setAutoDelete(true);
 	m_undo_buffer.clear();
 	qDebug("SignalManager::redo(): undo buffer flushed!");
     } else {
@@ -1465,22 +1522,23 @@ void SignalManager::redo()
     while (!redo_transaction->isEmpty()) {
 	UndoAction *undo_action;
 	UndoAction *redo_action;
-	
+
 	// unqueue the undo action
-	redo_transaction->setAutoDelete(false);
 	redo_action = redo_transaction->first();
+	redo_transaction->setAutoDelete(false);
 	redo_transaction->removeFirst();
+	redo_transaction->setAutoDelete(true);
 	Q_ASSERT(redo_action);
 	if (!redo_action) continue;
-	
+
 	// execute the redo operation
 	undo_action = redo_action->undo(*this, (undo_transaction != 0));
-	
+
 	// remove the old redo action if no longer used
 	if (redo_action != undo_action) {
 	    delete redo_action;
 	}
-	
+
 	// queue the action into the undo transaction
 	if (undo_action) {
 	    if (undo_transaction) {
@@ -1492,11 +1550,14 @@ void SignalManager::redo()
 	}
     }
 
+    // now the redo_transaction should be empty -> get rid of it
+    Q_ASSERT(redo_transaction->isEmpty());
+    delete redo_transaction;
+
     if (undo_transaction && (undo_transaction->count() <= 1)) {
 	// if there is not more than the UndoSelection action,
 	// there are no real undo actions -> no undo possible
 	qWarning("SignalManager::redo(): no undo possible");
-	m_undo_buffer.setAutoDelete(true);
 	m_undo_buffer.remove(undo_transaction);
     }
 
@@ -1527,7 +1588,7 @@ void SignalManager::setFileInfo(FileInfo &new_info, bool with_undo)
 {
     ThreadsafeX11Guard x11_guard;
 
-    if (with_undo) {
+    if (m_undo_enabled && with_undo) {
 	/* save data for undo */
 	UndoTransactionGuard undo_transaction(*this, i18n("modify file info"));
 	UndoFileInfo *undo = new UndoFileInfo(*this);
