@@ -47,7 +47,6 @@ class SignalWidget : public QWidget
 {
     Q_OBJECT
 
-    class InhibitRepaintGuard;
     friend class InhibitRepaintGuard;
 
 public:
@@ -334,6 +333,12 @@ private slots:
      */
     void refreshSignalLayer();
 
+    /**
+     * connected to the m_repaint_timer, called when it has
+     * elapsed and the signal has to be repainted
+     */
+    void timedRepaint();
+
 signals:
 
     /**
@@ -420,15 +425,15 @@ protected:
 	{
 	    m_widget.inhibitRepaint();
 	};
-	
+
 	/** Destructor, allows repaints */
 	~InhibitRepaintGuard() {
 	    m_widget.allowRepaint(m_repaint);
 	};
-	
+
 	/** reference to our owner */
 	SignalWidget &m_widget;
-	
+
 	/** true if repaint is needed after allow */
 	bool m_repaint;
     };
@@ -518,6 +523,7 @@ private:
     void setMouseMode(MouseMode mode);
 
 private:
+
     /** Pixmaps for buffering each layer */
     QPixmap *m_layer[3];
 
@@ -592,6 +598,9 @@ private:
      */
     int m_mouse_down_x;
 
+    /** timer for limiting the number of repaints per second */
+    QTimer m_repaint_timer;
+
 };
 
 #endif /* _SIGNAL_WIDGET_H_ */
