@@ -144,7 +144,7 @@ private slots:
      * @param bits resolution in bits
      */
     void setStatusInfo(unsigned int length, unsigned int tracks,
-                       unsigned int rate, unsigned int bits);
+                       double rate, unsigned int bits);
 
     /**
      * Called if the number of tracks has changed and updates
@@ -154,10 +154,12 @@ private slots:
 
     /**
      * Updates the number of selected samples in the status bar.
-     * @param samples number of selected samples
-     * @param ms length of the selected range [milliseconds]
+     * @param offset index of the first selected sample
+     * @param length number of selected samples
+     * @param rate sample rate [samples/second] for converting to time
      */
-    void setSelectedTimeInfo(unsigned int samples, double ms);
+    void setSelectedTimeInfo(unsigned int offset, unsigned int length,
+                             double rate);
 
     /**
      * Sets the descriptions of the last undo and redo action. If the
@@ -231,6 +233,21 @@ signals:
      */
     void sigSignalNameChanged(const QString &name);
 
+protected:
+
+    friend class RecordPlugin;
+
+    /**
+     * Closes the current file and creates a new empty signal.
+     * @param samples number of samples per track
+     * @param rate sample rate
+     * @param bits number of bits per sample
+     * @param tracks number of tracks
+     * @return zero if successful, -1 if failed or canceled
+     */
+    int newSignal(unsigned int samples, double rate,
+                  unsigned int bits, unsigned int tracks);
+
 protected:
 
     /** Updates the menu by enabling/disabling some entries */
@@ -267,28 +284,12 @@ protected:
      */
     int saveFileAs(bool selection = false);
 
-    /**
-     * Closes the current file and creates a new empty signal.
-     * @param samples number of samples per track
-     * @param rate sample rate
-     * @param bits number of bits per sample
-     * @param tracks number of tracks
-     */
-    int newSignal(unsigned int samples, double rate,
-                  unsigned int bits, unsigned int tracks);
-
     /**
      * Opens a file contained in the list of recent files.
      * @param str the entry contained in the list
      */
     int openRecent(const QString &str);
 
-    /**
-     * Sets a new resolution for saving in bits per sample.
-     * @param str str the resolution in string representation
-     */
-    int resolution(const QString &str);
-
     /** Updates the caption with the filename */
     void updateCaption();
 
@@ -343,9 +344,6 @@ private:
     /** menu manager for this window */
     MenuManager *m_menu_manager;
 
-    /** bits per sample to save with */
-    int m_save_bits;
-
     /** Timer used to let the pause button blink... */
     QTimer *m_pause_timer;
 
