@@ -31,7 +31,7 @@ class QLabel;
 class QResizeEvent;
 class KProgress;
 
-class FileProgress: public QSemiModal
+class FileProgress: public KDialog
 {
     Q_OBJECT
 public:
@@ -47,7 +47,7 @@ public:
      */
     FileProgress(QWidget *parent,
 	const QUrl &url, unsigned int size,
-	unsigned int samples, unsigned int rate, unsigned int bits,
+	unsigned int samples, double rate, unsigned int bits,
 	unsigned int tracks);
 
     /**
@@ -67,10 +67,23 @@ signals:
 public slots:
     /**
      * Advances the progress to a given position within the file.
-     * @param pos position within the file [0...m_size-1]
+     * @param pos position within the file, in samples
      */
     void setValue(unsigned int pos);
 
+    /**
+     * Like setValue, but takes position in bytes as argument
+     * @param pos position within the file, in bytes [0...m_size-1]
+     */
+    void setBytePosition(unsigned int pos);
+
+    /**
+     * Updates the length information, needed in stream mode.
+     * @param samples total number of samples, must be divided through
+     *        the number of tracks for getting the real length
+     */
+    void setLength(unsigned int samples);
+    
 protected slots:
 
     /**
@@ -103,7 +116,7 @@ protected:
      * @param layout the QGridLayout with the labels
      * @param text the content of the label, localized
      * @param row the row within the layout [0...rows-1]
-     * @param col the column within the layout [0...columns-1]
+     * @param column the column within the layout [0...columns-1]
      * @return the label if successful, 0 if failed
      * @internal
      */
@@ -129,6 +142,9 @@ protected:
     /** label with the url, shortened when too long */
     QLabel *m_lbl_url;
 
+    /** label with length info, changes in streaming mode */
+    QLabel *m_lbl_length;
+    
     /** progress bar */
     KProgress *m_progress;
 
@@ -147,6 +163,15 @@ protected:
     /** last displayed percent value */
     int m_last_percent;
 
+    /** number of bits per sample */
+    unsigned int m_bits_per_sample;
+
+    /** number of samples per second, used for output */
+    double m_sample_rate;
+
+    /** number of tracks */
+    unsigned int m_tracks;
+    
 };
 
 #endif /* _FILE_PROGRESS_H_ */
