@@ -20,7 +20,7 @@
 
 #include "config.h"
 #include <qobject.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qdict.h>
 #include <qpixmap.h>
 #include <qstring.h>
@@ -147,7 +147,7 @@ public:
     /**
      * Returns the positional index of a child node, identified by
      * it's menu id.
-     * @param menu id of the child
+     * @param id the menu item id of the child
      * @return index [0..n] or -1 f not found
      */
     virtual int getChildIndex(int id);
@@ -188,7 +188,7 @@ public:
 
     /**
      * Sets or removes the checkmark from a menu node.
-     * @param id the item's menu id
+     * @param item the item's menu id
      * @param check true to set the mark, false to remove
      */
     virtual void setItemChecked(int item, bool check);
@@ -400,14 +400,13 @@ private slots:
     /**
      * Informs the node that the enabled state of it's parent might
      * have changed.
-     * @param enable true if the item has been enabled, false if disabled
      */
     void slotParentEnableChanged();
 
 protected:
 
     /** list with pointers to child menus */
-    QList<MenuNode> m_children;
+    QPtrList<MenuNode> m_children;
 
     /** list of group names the item belongs to */
     QStringList m_groups;
