@@ -94,7 +94,7 @@ public:
     /**
      * Sets a delay value to a new value.
      * @param index internal index [0...count-1]
-     * @param delay new delay value
+     * @param newval new delay value
      */
     void setDelay(unsigned int index, unsigned int newval);
 
@@ -112,10 +112,10 @@ private:
     unsigned int m_rate;
 
     /** array of coefficients */
-    QArray<double> m_coeff;
+    QMemArray<double> m_coeff;
 
     /** array of delay times */
-    QArray<int> m_delay;
+    QMemArray<int> m_delay;
 
 };
 
