@@ -38,7 +38,7 @@ public:
     MultiTrackReader();
 
     /** Destructor */
-    virtual ~MultiTrackReader() {};
+    virtual ~MultiTrackReader();
 
     /** Returns true if one of the readers has reached eof() */
     virtual bool eof() const;
@@ -54,7 +54,7 @@ public:
     };
 
     /** @see QPtrVector::clear() */
-    inline virtual void clear() { QPtrVector<SampleReader>::clear(); };
+    virtual void clear();
 
     /** @see QPtrVector::isEmpty() */
     inline virtual bool isEmpty() {
@@ -90,7 +90,7 @@ public slots:
 
     /** Resets all readers to zero */
     void reset();
-    
+
 private slots:
 
     /**
