@@ -29,7 +29,7 @@
 KWAVE_PLUGIN(AboutPlugin,"about","Ralf Waspe & Gilles Caulier");
 
 //***************************************************************************
-AboutPlugin::AboutPlugin(PluginContext &c)
+AboutPlugin::AboutPlugin(const PluginContext &c)
     :KwavePlugin(c)
 {
     i18n("about");
