@@ -26,7 +26,7 @@
 KWAVE_PLUGIN(WavCodecPlugin,"codec_wav","Thomas Eschenbacher");
 
 /***************************************************************************/
-WavCodecPlugin::WavCodecPlugin(PluginContext &c)
+WavCodecPlugin::WavCodecPlugin(const PluginContext &c)
     :KwavePlugin(c), m_decoder(0), m_encoder(0)
 {
     i18n("codec_wav");
@@ -35,6 +35,8 @@ WavCodecPlugin::WavCodecPlugin(PluginContext &c)
 /***************************************************************************/
 WavCodecPlugin::~WavCodecPlugin()
 {
+    m_encoder = 0;
+    m_decoder = 0;
 }
 
 /***************************************************************************/
