@@ -22,7 +22,7 @@
 #include <qobject.h>
 #include <qstring.h>
 
-#include "PlayBackDevice.h"
+#include "libkwave/PlayBackDevice.h"
 
 class PlayBackOSS: public PlayBackDevice
 {
@@ -39,7 +39,7 @@ public:
      * Opens the device for playback.
      * @see PlayBackDevice::open
      */
-    virtual QString open(const QString &device, unsigned int rate,
+    virtual QString open(const QString &device, double rate,
                          unsigned int channels, unsigned int bits,
                          unsigned int bufbase);
 
@@ -47,7 +47,7 @@ public:
      * Writes an array of samples to the output device.
      * @see PlayBackDevice::write
      */
-    virtual int write(QArray<sample_t> &samples);
+    virtual int write(QMemArray<sample_t> &samples);
 
     /**
      * Closes the output device.
@@ -67,7 +67,7 @@ protected:
     int m_handle;
 
     /** Playback rate [samples/second] */
-    unsigned int m_rate;
+    double m_rate;
 
     /** Number of channels */
     unsigned int m_channels;
