@@ -24,7 +24,7 @@
 #include <artsc.h>
 
 #include "mt/Mutex.h"
-#include "PlayBackDevice.h"
+#include "libkwave/PlayBackDevice.h"
 
 class PlayBackArts: public PlayBackDevice
 {
@@ -41,7 +41,7 @@ public:
      * Opens the device for playback.
      * @see PlayBackDevice::open
      */
-    virtual QString open(const QString &, unsigned int rate,
+    virtual QString open(const QString &, double rate,
                          unsigned int channels, unsigned int bits,
                          unsigned int bufbase);
 
@@ -49,7 +49,7 @@ public:
      * Writes an array of samples to the output device.
      * @see PlayBackDevice::write
      */
-    virtual int write(QArray<sample_t> &samples);
+    virtual int write(QMemArray<sample_t> &samples);
 
     /**
      * Closes the output device.
@@ -76,7 +76,7 @@ protected:
     arts_stream_t m_stream;
 
     /** Playback rate [samples/second] */
-    unsigned int m_rate;
+    double m_rate;
 
     /** Number of channels */
     unsigned int m_channels;
