@@ -25,6 +25,7 @@
 #include <qprogressbar.h>
 #include <qslider.h>
 
+#include <kapplication.h> // for invokeHelp
 #include <kcombobox.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -84,7 +85,8 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
                            RecordController *controller)
     :RecordDlg(parent,0), m_state(REC_EMPTY), m_params(),
      m_supported_resolutions(), m_buffer_progress_count(0),
-     m_buffer_progress_total(0), m_buffer_progress_timer(this)
+     m_buffer_progress_total(0), m_buffer_progress_timer(this),
+     m_record_enabled(true), m_samples_recorded(0)
 {
     /* get initial parameters */
     m_params.fromList(params);
@@ -99,9 +101,13 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
 
     // pre-record
     STD_SETUP_SLIDER(pre_record_enabled, pre_record_time, RecordPre);
+    connect(chkRecordPre, SIGNAL(toggled(bool)),
+            this,         SLOT(preRecordingChecked(bool)));
+    connect(sbRecordPre,  SIGNAL(valueChanged(int)),
+            this,         SLOT(preRecordingTimeChanged(int)));
 
     // record time
-    STD_SETUP_SLIDER(record_time_limited, record_time, RecordTime);
+    STD_SETUP(record_time_limited, record_time, RecordTime);
 
     // record trigger
     STD_SETUP_SLIDER(record_trigger_enabled, record_trigger, RecordTrigger);
@@ -165,6 +171,11 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     connect(chkDisplayLevelMeter, SIGNAL(toggled(bool)),
             this, SLOT(displayLevelMeterChecked(bool)));
 
+    connect(chkRecordTime, SIGNAL(toggled(bool)),
+            this, SLOT(recordTimeChecked(bool)));
+    connect(sbRecordTime, SIGNAL(valueChanged(int)),
+            this, SLOT(recordTimeChanged(int)));
+
     connect(chkRecordTrigger, SIGNAL(toggled(bool)),
             this, SLOT(triggerChecked(bool)));
     connect(sbRecordTrigger, SIGNAL(valueChanged(int)),
@@ -205,6 +216,10 @@ RecordDialog::RecordDialog(QWidget *parent, QStringList &params,
     connect(&m_buffer_progress_timer, SIGNAL(timeout()),
             this, SLOT(updateBufferProgressBar()));
 
+    // help button
+    connect(btHelp, SIGNAL(clicked()),
+            this,   SLOT(invokeHelp()));
+
     // set the initial state of the dialog to "Reset/Empty"
     setState(REC_EMPTY);
 }
@@ -598,6 +613,7 @@ void RecordDialog::setState(RecordState state)
     bool enable_stop = false;
     bool enable_record = false;
     bool enable_settings = false;
+    bool enable_trigger = false;
 
     m_state = state;
     switch (state) {
@@ -608,6 +624,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = false;
 	    enable_record   = m_params.device_name.length();
 	    enable_settings = true;
+	    enable_trigger  = true;
 	    break;
 	case REC_BUFFERING:
 	    lbl_state->setText(i18n("buffering..."));
@@ -616,6 +633,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = true;
 	    enable_record   = true; /* acts as "trigger now" */
 	    enable_settings = false;
+	    enable_trigger  = true;
 	    break;
 	case REC_PRERECORDING:
 	    lbl_state->setText(i18n("prerecording..."));
@@ -624,6 +642,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = true;
 	    enable_record   = true;
 	    enable_settings = false;
+	    enable_trigger  = true;
 	    break;
 	case REC_WAITING_FOR_TRIGGER:
 	    lbl_state->setText(i18n("waiting for trigger..."));
@@ -632,6 +651,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = true;
 	    enable_record   = true; /* acts as "trigger now" */
 	    enable_settings = false;
+	    enable_trigger  = true;
 	    break;
 	case REC_RECORDING:
 	    lbl_state->setText(i18n("recording..."));
@@ -640,6 +660,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = true;
 	    enable_record   = false;
 	    enable_settings = false;
+	    enable_trigger  = false;
 	    break;
 	case REC_PAUSED:
 	    lbl_state->setText(i18n("paused"));
@@ -648,6 +669,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = true;
 	    enable_record   = true; /* used for "continue" */
 	    enable_settings = false;
+	    enable_trigger  = false;
 	    break;
 	case REC_DONE:
 	    lbl_state->setText(i18n("done."));
@@ -656,6 +678,7 @@ void RecordDialog::setState(RecordState state)
 	    enable_stop     = false;
 	    enable_record   = true;
 	    enable_settings = true;
+	    enable_trigger  = true;
 	    break;
     }
 
@@ -663,16 +686,26 @@ void RecordDialog::setState(RecordState state)
     btNew->setEnabled(enable_new);
     btPause->setEnabled(enable_pause);
     btStop->setEnabled(enable_stop);
-    btRecord->setEnabled(enable_record);
+    m_record_enabled = enable_record;
+    updateRecordButton();
 
     // enable disable all controls (groups) for setup
+    chkRecordPre->setEnabled(enable_settings);
+    sbRecordPre->setEnabled(enable_settings &&
+                            chkRecordPre->isChecked());
+    slRecordPre->setEnabled(enable_settings &&
+                            chkRecordPre->isChecked());
+
+    chkRecordTime->setEnabled(enable_settings);
+    sbRecordTime->setEnabled(enable_settings &&
+                             chkRecordTime->isChecked());
     chkRecordTrigger->setEnabled(enable_settings);
 
-// it is not really necessary to disable these ;-)
-//     sbRecordTrigger->setEnabled(enable_settings &&
-//                                 chkRecordTrigger->isChecked());
-//     slRecordTrigger->setEnabled(enable_settings &&
-//                                 chkRecordTrigger->isChecked());
+    // it is not really necessary to disable these ;-)
+    sbRecordTrigger->setEnabled(enable_trigger &&
+                                chkRecordTrigger->isChecked());
+    slRecordTrigger->setEnabled(enable_trigger &&
+                                chkRecordTrigger->isChecked());
 
     grpFormat->setEnabled(enable_settings);
     grpSource->setEnabled(enable_settings);
@@ -704,6 +737,35 @@ void RecordDialog::updateBufferState(unsigned int count, unsigned int total)
 
 }
 
+//***************************************************************************
+void RecordDialog::preRecordingChecked(bool enabled)
+{
+    m_params.pre_record_enabled = enabled;
+    emit sigPreRecordingChanged(enabled);
+}
+
+//***************************************************************************
+void RecordDialog::preRecordingTimeChanged(int time)
+{
+    m_params.pre_record_time = time;
+}
+
+//***************************************************************************
+void RecordDialog::recordTimeChecked(bool limited)
+{
+    m_params.record_time_limited = limited;
+    emit sigRecordTimeChanged(limited ? sbRecordTime->value() : -1);
+}
+
+//***************************************************************************
+void RecordDialog::recordTimeChanged(int limit)
+{
+    m_params.record_time = limit;
+    emit sigRecordTimeChanged(chkRecordTime->isChecked() ?
+                              limit : -1);
+    updateRecordButton();
+}
+
 //***************************************************************************
 void RecordDialog::triggerChecked(bool enabled)
 {
@@ -724,7 +786,7 @@ void RecordDialog::displayLevelMeterChecked(bool enabled)
     Q_ASSERT(level_meter);
     if (!level_meter) return;
     if (!enabled) {
-	level_meter->setTracks(0);    
+	level_meter->setTracks(0);
 	level_meter->reset();
     }
     level_meter->setEnabled(enabled);
@@ -755,5 +817,33 @@ void RecordDialog::updateEffects(unsigned int track,
 
 }
 
+//***************************************************************************
+void RecordDialog::setRecordedSamples(unsigned int samples_recorded)
+{
+    // if (!m_params.record_time_limited) return; // not of interest
+    m_samples_recorded = samples_recorded;
+    updateRecordButton();
+}
+
+//***************************************************************************
+void RecordDialog::updateRecordButton()
+{
+    bool old_enable = btRecord->isEnabled();
+    bool new_enable;
+
+    // enabled if not disabled by status and also not limited or
+    // less than the limit has been recorded
+    new_enable = m_record_enabled && (!m_params.record_time_limited ||
+        (m_samples_recorded < m_params.record_time * m_params.sample_rate));
+
+    if (new_enable != old_enable) btRecord->setEnabled(new_enable);
+}
+
+//***************************************************************************
+void RecordDialog::invokeHelp()
+{
+    kapp->invokeHelp("recording");
+}
+
 //***************************************************************************
 //***************************************************************************
