@@ -33,6 +33,7 @@
 #include "libkwave/FileInfo.h"
 #include "libkwave/InsertMode.h"
 #include "libkwave/Sample.h"
+#include "libkwave/SampleFIFO.h"
 #include "libkwave/SampleFormat.h"
 #include "libkwave/SampleWriter.h"
 
@@ -50,11 +51,14 @@
 KWAVE_PLUGIN(RecordPlugin,"record","Thomas Eschenbacher");
 
 //***************************************************************************
-RecordPlugin::RecordPlugin(PluginContext &context)
-    :KwavePlugin(context), m_state(REC_EMPTY), m_device(0),
-     m_dialog(0), m_thread(0), m_decoder(0), m_writers(),
-     m_buffers_recorded(0), m_inhibit_count(0), m_trigger_value()
+RecordPlugin::RecordPlugin(const PluginContext &context)
+    :KwavePlugin(context), m_controller(),
+     m_state(REC_EMPTY), m_device(0),
+     m_dialog(0), m_thread(0), m_decoder(0), m_prerecording_queue(),
+     m_writers(), m_buffers_recorded(0), m_inhibit_count(0),
+     m_trigger_value()
 {
+    m_prerecording_queue.setAutoDelete(true);
     i18n("record");
 }
 
@@ -82,11 +86,9 @@ QStringList *RecordPlugin::setup(QStringList &previous_params)
 {
     qDebug("RecordPlugin::setup");
 
-    // use a new record controller
-    RecordController controller;
-
     // create the setup dialog
-    m_dialog = new RecordDialog(parentWidget(), previous_params, &controller);
+    m_dialog = new RecordDialog(parentWidget(), previous_params,
+                                &m_controller);
     Q_ASSERT(m_dialog);
     if (!m_dialog) return 0;
 
@@ -101,43 +103,41 @@ QStringList *RecordPlugin::setup(QStringList &previous_params)
 
     // connect some signals of the setup dialog
     connect(m_dialog, SIGNAL(deviceChanged(const QString &)),
-            this, SLOT(changeDevice(const QString &)));
+            this,     SLOT(changeDevice(const QString &)));
     connect(m_dialog, SIGNAL(sigTracksChanged(unsigned int)),
-            this, SLOT(changeTracks(unsigned int)));
+            this,     SLOT(changeTracks(unsigned int)));
     connect(m_dialog, SIGNAL(sampleRateChanged(double)),
-            this, SLOT(changeSampleRate(double)));
+            this,     SLOT(changeSampleRate(double)));
     connect(m_dialog, SIGNAL(sigCompressionChanged(int)),
-            this, SLOT(changeCompression(int)));
+            this,     SLOT(changeCompression(int)));
     connect(m_dialog, SIGNAL(sigBitsPerSampleChanged(unsigned int)),
-            this, SLOT(changeBitsPerSample(unsigned int)));
+            this,     SLOT(changeBitsPerSample(unsigned int)));
     connect(m_dialog, SIGNAL(sigSampleFormatChanged(int)),
-            this, SLOT(changeSampleFormat(int)));
+            this,     SLOT(changeSampleFormat(int)));
     connect(m_dialog, SIGNAL(sigBuffersChanged()),
-            this, SLOT(buffersChanged()));
-
-    connect(m_dialog, SIGNAL(sigTriggerChanged(bool)),
-            &controller, SLOT(enableTrigger(bool)));
-    controller.enableTrigger(m_dialog->params().record_trigger_enabled);
+            this,     SLOT(buffersChanged()));
+    connect(this,     SIGNAL(sigRecordedSamples(unsigned int)),
+            m_dialog, SLOT(setRecordedSamples(unsigned int)));
+    connect(m_dialog,      SIGNAL(sigTriggerChanged(bool)),
+            &m_controller, SLOT(enableTrigger(bool)));
+    m_controller.enableTrigger(m_dialog->params().record_trigger_enabled);
+    connect(m_dialog, SIGNAL(sigPreRecordingChanged(bool)),
+            &m_controller, SLOT(enablePrerecording(bool)));
+    m_controller.enablePrerecording(m_dialog->params().pre_record_enabled);
 
     // connect the record controller and this
-    connect(&controller, SIGNAL(sigReset(bool &)),
-            this, SLOT(resetRecording(bool &)));
-    connect(&controller, SIGNAL(sigStartRecord()),
-            this, SLOT(startRecording()));
-    connect(&controller, SIGNAL(sigStopRecord(int)),
-            &controller, SLOT(deviceRecordStopped(int)));
-    connect(&controller, SIGNAL(stateChanged(RecordState)),
-            this, SLOT(stateChanged(RecordState)));
+    connect(&m_controller, SIGNAL(sigReset(bool &)),
+            this,          SLOT(resetRecording(bool &)));
+    connect(&m_controller, SIGNAL(sigStartRecord()),
+            this,          SLOT(startRecording()));
+    connect(&m_controller, SIGNAL(sigStopRecord(int)),
+            &m_controller, SLOT(deviceRecordStopped(int)));
+    connect(&m_controller, SIGNAL(stateChanged(RecordState)),
+            this,          SLOT(stateChanged(RecordState)));
 
     // connect record controller and record thread
-    connect(this,        SIGNAL(sigStarted()),
-            &controller, SLOT(deviceRecordStarted()));
-    connect(this,        SIGNAL(sigBufferFull()),
-            &controller, SLOT(deviceBufferFull()));
-    connect(this, SIGNAL(sigTriggerReached()),
-            &controller, SLOT(deviceTriggerReached()));
-    connect(m_thread,    SIGNAL(stopped(int)),
-            &controller, SLOT(deviceRecordStopped(int)));
+    connect(m_thread,      SIGNAL(stopped(int)),
+            &m_controller, SLOT(deviceRecordStopped(int)));
 
     // connect us to the record thread
     connect(m_thread, SIGNAL(stopped(int)),
@@ -159,8 +159,12 @@ QStringList *RecordPlugin::setup(QStringList &previous_params)
 	list = 0;
     }
 
-    if (m_dialog) delete m_dialog;
-    m_dialog = 0;
+    if (m_dialog) {
+	fileInfo().setLength(signalLength());
+	fileInfo().setTracks(m_dialog->params().tracks);
+	delete m_dialog;
+	m_dialog = 0;
+    }
 
     if (m_thread) delete m_thread;
     m_thread = 0;
@@ -168,6 +172,9 @@ QStringList *RecordPlugin::setup(QStringList &previous_params)
     if (m_decoder) delete m_decoder;
     m_decoder = 0;
 
+    // flush away all prerecording buffers
+    m_prerecording_queue.clear();
+
     return list;
 }
 
@@ -176,7 +183,7 @@ void RecordPlugin::changeDevice(const QString &dev)
 {
     Q_ASSERT(m_dialog);
     if (!m_dialog) return;
-    qDebug("RecordPlugin::changeDevice("+dev+")");
+    qDebug("RecordPlugin::changeDevice(%s)", dev.local8Bit().data());
 
     InhibitRecordGuard _lock(*this); // don't record while settings change
 
@@ -507,13 +514,17 @@ void RecordPlugin::resetRecording(bool &accepted)
     m_writers.flush();
     m_writers.resize(0);
     m_buffers_recorded = 0;
+
+    m_controller.setEmpty(true);
+    emit sigRecordedSamples(0);
 }
 
 //***************************************************************************
 void RecordPlugin::setupRecordThread()
 {
     Q_ASSERT(m_thread);
-    if (!m_thread) return;
+    Q_ASSERT(m_dialog);
+    if (!m_thread || !m_dialog) return;
 
     // stop the thread if necessary (should never happen)
     Q_ASSERT(!m_thread->running());
@@ -524,16 +535,19 @@ void RecordPlugin::setupRecordThread()
     if (m_decoder) delete m_decoder;
     m_decoder = 0;
 
+    // our own reference to the record parameters
+    const RecordParams &params = m_dialog->params();
+
     // create a decoder for the current sample format
-    switch (m_dialog->params().compression) {
+    switch (params.compression) {
 	case AF_COMPRESSION_NONE:
-	    switch (m_dialog->params().sample_format) {
+	    switch (params.sample_format) {
 		case AF_SAMPFMT_UNSIGNED:
 		case AF_SAMPFMT_TWOSCOMP:
 		    // decoder for all linear formats
 		    m_decoder = new SampleDecoderLinear(
-			m_dialog->params().sample_format,
-			m_dialog->params().bits_per_sample
+			params.sample_format,
+			params.bits_per_sample
 		    );
 		    break;
 		default:
@@ -558,16 +572,36 @@ void RecordPlugin::setupRecordThread()
 	return;
     }
 
+    // set up the prerecording queues
+    m_prerecording_queue.clear();
+    if (params.pre_record_enabled) {
+	// prepare a queue for each track
+	m_prerecording_queue.resize(params.tracks);
+	unsigned int fifo_depth = (unsigned int)ceil((
+	    params.pre_record_time * params.sample_rate));
+
+	for (unsigned int track=0; track < params.tracks; ++track) {
+	    SampleFIFO *fifo = new SampleFIFO(fifo_depth);
+	    m_prerecording_queue.insert(track, fifo);
+	    Q_ASSERT(fifo);
+	    if (!fifo) {
+		m_prerecording_queue.clear();
+		KMessageBox::sorry(m_dialog, i18n("Out of memory"));
+		return;
+	    }
+	}
+    }
+
     // set up the recording trigger values
-    m_trigger_value.resize(m_dialog->params().tracks);
+    m_trigger_value.resize(params.tracks);
     m_trigger_value.fill((double)0.0);
 
     // set up the record thread
     m_thread->setRecordDevice(m_device);
-    unsigned int buf_count = m_dialog->params().buffer_count;
-    unsigned int buf_size  = m_dialog->params().tracks *
+    unsigned int buf_count = params.buffer_count;
+    unsigned int buf_size  = params.tracks *
                              m_decoder->rawBytesPerSample() *
-                            (1 << m_dialog->params().buffer_size);
+                            (1 << params.buffer_size);
     m_thread->setBuffers(buf_count, buf_size);
 }
 
@@ -640,7 +674,7 @@ void RecordPlugin::startRecording()
     }
 
     // now the recording can be considered to be started
-    emit sigStarted();
+    m_controller.deviceRecordStarted();
 }
 
 //***************************************************************************
@@ -669,6 +703,9 @@ void RecordPlugin::recordStopped(int reason)
     m_writers.flush();
     qDebug("RecordPlugin::recordStopped(): wrote %u samples",
            m_writers.last());
+
+    // flush away all prerecording buffers
+    m_prerecording_queue.clear();
 }
 
 //***************************************************************************
@@ -734,6 +771,20 @@ void RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
     char *src = raw_data.data();
     char *dst = dest.data();
     src += (track * bytes_per_sample);
+
+#if 0
+    static int saw[2] = {0, 0};
+
+    // simple sawtooth generator, nice for debugging
+    while (samples--) {
+	for (unsigned int byte=0; byte < bytes_per_sample; byte++) {
+	    *dst = (saw[track] / 128);
+	    dst++;
+	}
+	saw[track]++;
+	if (saw[track] > (SAMPLE_MAX/1024)) saw[track] = (SAMPLE_MIN/1024);
+    }
+#else
     while (samples--) {
 	for (unsigned int byte=0; byte < bytes_per_sample; byte++) {
 	    *dst = *src;
@@ -742,6 +793,7 @@ void RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 	}
 	src += increment;
     }
+#endif
 }
 
 //***************************************************************************
@@ -816,14 +868,73 @@ bool RecordPlugin::checkTrigger(unsigned int track,
     }
     m_trigger_value[track] = y;
 
-    qDebug(">> level=%0.3g, trigger=%0.3g", y, trigger);
+    qDebug(">> level=%5.3g, trigger=%5.3g", y, trigger);
 
     return false;
 }
 
+//***************************************************************************
+void RecordPlugin::enqueuePrerecording(unsigned int track,
+                                       const QMemArray<sample_t> &decoded)
+{
+    Q_ASSERT(m_dialog);
+    Q_ASSERT(track < m_prerecording_queue.size());
+    if (!m_dialog) return;
+    if (track >= m_prerecording_queue.size()) return;
+
+    // append the array with decoded sample to the prerecording buffer
+    SampleFIFO *fifo = m_prerecording_queue.at(track);
+    Q_ASSERT(fifo);
+    if (fifo) fifo->put(decoded);
+}
+
+//***************************************************************************
+void RecordPlugin::flushPrerecordingQueue()
+{
+    if (!m_prerecording_queue.size()) return;
+    Q_ASSERT(m_dialog);
+    Q_ASSERT(m_thread);
+    Q_ASSERT(m_decoder);
+    if (!m_dialog || !m_thread || !m_decoder) return;
+
+    const RecordParams &params = m_dialog->params();
+    const unsigned int tracks = params.tracks;
+    Q_ASSERT(tracks);
+    if (!tracks) return;
+    Q_ASSERT(tracks == m_writers.count());
+    if (!tracks || (tracks != m_writers.count())) return;
+
+    for (unsigned int track=0; track < tracks; ++track) {
+	SampleFIFO *fifo = m_prerecording_queue.at(track);
+	Q_ASSERT(fifo);
+	if (!fifo) continue;
+	Q_ASSERT(fifo->length());
+	if (!fifo->length()) continue;
+
+	// push all buffers to the writer, starting at the tail
+	SampleWriter *writer = m_writers[track];
+	Q_ASSERT(writer);
+	if (writer) {
+	    fifo->align();
+	    *writer << fifo->data();
+	}
+
+	// discard the FIFO and it's content
+	fifo->resize(0);
+    }
+
+    // the queues are no longer needed
+    m_prerecording_queue.clear();
+
+    // we have transferred data to the writers, we are no longer empty
+    m_controller.setEmpty(false);
+}
+
 //***************************************************************************
 void RecordPlugin::processBuffer(QByteArray buffer)
 {
+    bool recording_done = false;
+
 //    qDebug("RecordPlugin::processBuffer()");
     Q_ASSERT(m_dialog);
     Q_ASSERT(m_thread);
@@ -833,13 +944,27 @@ void RecordPlugin::processBuffer(QByteArray buffer)
     // we received a buffer -> update the progress bar
     updateBufferProgressBar();
 
-    // split into several single buffers
     const RecordParams &params = m_dialog->params();
     const unsigned int tracks = params.tracks;
     Q_ASSERT(tracks);
-
     const unsigned int bytes_per_sample = m_decoder->rawBytesPerSample();
-    const unsigned int samples = buffer.size() / bytes_per_sample / tracks;
+    unsigned int samples = buffer.size() / bytes_per_sample / tracks;
+
+    // check for reached recording time limit if enabled
+    if (params.record_time_limited) {
+	const unsigned int already_recorded = m_writers.last()+1;
+	const unsigned int limit = (unsigned int)rint(
+	    params.record_time * params.sample_rate);
+	if (already_recorded + samples >= limit) {
+	    // reached end of recording time, we are full
+	    if (m_state == REC_RECORDING) {
+		samples = (limit > already_recorded) ?
+		          (limit - already_recorded) : 0;
+		buffer.resize(samples * tracks * bytes_per_sample);
+	    }
+	    recording_done = true;
+	}
+    }
 
     QByteArray buf;
     buf.resize(bytes_per_sample * samples);
@@ -854,18 +979,26 @@ void RecordPlugin::processBuffer(QByteArray buffer)
     // check for trigger
     // note: this might change the state, which affects the
     //       processing all tracks !
-    if (m_state == REC_WAITING_FOR_TRIGGER) {
+    if ((m_state == REC_WAITING_FOR_TRIGGER) ||
+        ((m_state == REC_PRERECORDING) && (params.record_trigger_enabled)))
+    {
 	for (unsigned int track=0; track < tracks; ++track) {
 	    // split off and decode buffer with current track
 	    split(buffer, buf, bytes_per_sample, track, tracks);
 	    m_decoder->decode(buf, decoded);
 	    if (checkTrigger(track, decoded)) {
-		emit sigTriggerReached();
+		m_controller.deviceTriggerReached();
 		break;
 	    }
 	}
     }
 
+    if ((m_state == REC_RECORDING) && (!m_prerecording_queue.isEmpty())) {
+	// flush all prerecorded buffers to the output
+	flushPrerecordingQueue();
+    }
+
+    // decode and care for all special effects, meters and so on
     for (unsigned int track=0; track < tracks; ++track) {
 	// split off and decode buffer with current track
 	split(buffer, buf, bytes_per_sample, track, tracks);
@@ -873,29 +1006,36 @@ void RecordPlugin::processBuffer(QByteArray buffer)
 
 	// update the level meter and other effects
 	m_dialog->updateEffects(track, decoded);
+    }
 
-	switch (m_state) {
+    // if the first buffer is full -> leave REC_BUFFERING
+    if ((m_state==REC_BUFFERING) && (m_buffers_recorded > 1) && buffer.size())
+	    m_controller.deviceBufferFull();
+
+    // use a copy of the state, in case it changes below ;-)
+    RecordState state = m_state;
+    for (unsigned int track=0; track < tracks; ++track) {
+	switch (state) {
 	    case REC_EMPTY:
 		break;
 	    case REC_BUFFERING:
-		// first buffer is full
-		// -> leave REC_BUFFERING
-		if ((m_buffers_recorded > 1) && buffer.size())
-		    emit sigBufferFull();
+	    case REC_WAITING_FOR_TRIGGER:
+		// already handled before...
 		break;
 	    case REC_PRERECORDING:
 		// enqueue the buffers into a FIFO
-		break;
-	    case REC_WAITING_FOR_TRIGGER:
-		// already handled before...
+		enqueuePrerecording(track, decoded);
 		break;
 	    case REC_RECORDING: {
 		// put the decoded track data into the buffer
 		Q_ASSERT(tracks == m_writers.count());
-		if (!tracks || (tracks != m_writers.count())) return;
+		if (!tracks || (tracks != m_writers.count())) break;
+
 		SampleWriter *writer = m_writers[track];
 		Q_ASSERT(writer);
 		if (writer) (*writer) << decoded;
+		m_controller.setEmpty(false);
+
 		break;
 	    }
 	    case REC_PAUSED:
@@ -905,6 +1045,15 @@ void RecordPlugin::processBuffer(QByteArray buffer)
 	}
     }
 
+    // update the number of recorded samples
+    emit sigRecordedSamples(m_writers.last()+1);
+
+    // if this was the last received buffer, change state
+    if (recording_done && (m_state != REC_DONE) && (m_state != REC_EMPTY)) {
+	m_controller.actionStop();
+	return;
+    }
+
 }
 
 //***************************************************************************
