@@ -19,8 +19,9 @@
 #define _RECORD_PLUGIN_H_
 
 #include "config.h"
-#include <qmemarray.h>
 #include <qcstring.h>
+#include <qmemarray.h>
+#include <qptrvector.h>
 #include "libkwave/KwavePlugin.h"
 #include "libkwave/MultiTrackWriter.h"
 #include "libkwave/Sample.h"
@@ -33,6 +34,7 @@ class RecordDevice;
 class RecordDialog;
 class RecordThread;
 class SampleDecoder;
+class SampleFIFO;
 
 class RecordPlugin: public KwavePlugin
 {
@@ -40,7 +42,7 @@ class RecordPlugin: public KwavePlugin
 public:
 
     /** Constructor */
-    RecordPlugin(PluginContext &c);
+    RecordPlugin(const PluginContext &c);
 
     /** Destructor */
     virtual ~RecordPlugin();
@@ -50,14 +52,8 @@ public:
 
 signals:
 
-    /** emitted when the recording has been started */
-    void sigStarted();
-
-    /** emitted when the record buffer has been filled */
-    void sigBufferFull();
-
-    /** emitted when the trigger level has been reached */
-    void sigTriggerReached();
+    /** emitted to promote the recording progress to the dialog */
+    void sigRecordedSamples(unsigned int samples_recorded);
 
 protected:
 
@@ -174,14 +170,30 @@ private:
                unsigned int track,
                unsigned int tracks);
 
+    /**
+     * Enqueue a buffer with decoded samples into a prerecording
+     * buffer of the corresponding track.
+     *
+     * @param track index of the track [0...tracks-1]
+     * @param decoded array with decoded samples, in Kwave's internal format
+     */
+    void enqueuePrerecording(unsigned int track,
+                             const QMemArray<sample_t> &decoded);
+
+    /**
+     * Flush the content of the prerecording queue to the output
+     * @see m_writers
+     */
+    void flushPrerecordingQueue();
+
 private:
 
+    /** controller for the recording engine */
+    RecordController m_controller;
+
     /** global state of the plugin */
     RecordState m_state;
 
-    /** record control: pre-record enabled */
-    bool m_prerecord_enabled;
-
     /** device used for recording */
     RecordDevice *m_device;
 
@@ -194,6 +206,12 @@ private:
     /** decoder for converting raw data to samples */
     SampleDecoder *m_decoder;
 
+    /**
+     * set of queues for buffering prerecording data, one for each
+     * track
+     */
+    QPtrVector<SampleFIFO> m_prerecording_queue;
+
     /** sink for the audio data */
     MultiTrackWriter m_writers;
 
