@@ -26,10 +26,13 @@
 #include <qstring.h>
 #include <qimage.h>
 
+#include <gsl/gsl_complex.h>
+#include <gsl/gsl_fft.h>
+#include <gsl/gsl_fft_complex.h>
+
 #include <kapp.h>
 
 #include "mt/SignalProxy.h"
-#include "libkwave/gsl_fft.h"
 #include "libkwave/KwavePlugin.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/Sample.h"
@@ -69,7 +72,7 @@ private:
 };
 
 //***************************************************************************
-SonagramPlugin::SonagramPlugin(PluginContext &c)
+SonagramPlugin::SonagramPlugin(const PluginContext &c)
     :KwavePlugin(c), m_sonagram_window(0), m_selected_channels(),
      m_first_sample(0), m_last_sample(0), m_stripes(0), m_fft_points(0),
      m_window_type(WINDOW_FUNC_NONE), m_color(true), m_track_changes(true),
@@ -129,7 +132,7 @@ int SonagramPlugin::interpreteParameters(QStringList &params)
 
     // evaluate the parameter list
     if (params.count() != 5) return -EINVAL;
-	
+
     param = params[0];
     m_fft_points = param.toUInt(&ok);
     Q_ASSERT(ok);
@@ -261,15 +264,15 @@ void SonagramPlugin::run(QStringList /* params */)
 	for (stripe_nr = 0; stripe_nr < m_stripes; stripe_nr++) {
 //	    qDebug("SonagramPlugin::run(): calculating stripe %d of %d",
 //	        stripe_nr,m_stripes);
-	
+
 	    // create a new stripe data array
 	    stripe_data = new QByteArray(m_fft_points/2);
 	    Q_ASSERT(stripe_data);
 	    if (!stripe_data) continue;
-	
+
 	    // calculate one stripe
 	    calculateStripe(source, m_fft_points, *stripe_data);
-	
+
 	    StripeInfoPrivate *stripe_info = new
 		StripeInfoPrivate(stripe_nr, *stripe_data);
 
@@ -284,14 +287,14 @@ void SonagramPlugin::run(QStringList /* params */)
 		    if (m_cmd_shutdown) break; // ###
 		}
 	    }
-	
+
 	    delete stripe_data;
 	    delete stripe_info;
 	    yield();
-	
+
 	    if (m_cmd_shutdown) break; // ###
 	}
-	
+
 	m_cmd_shutdown = true;
     }
 
@@ -324,6 +327,9 @@ void SonagramPlugin::insertStripe()
 void SonagramPlugin::calculateStripe(MultiTrackReader &source,
 	const unsigned int points, QByteArray &output)
 {
+    gsl_fft_complex_wavetable *wavetable = 0;
+    gsl_fft_complex_workspace *workspace = 0;
+
     // first initialize the output to zeroes in case of errors
     output.fill(0);
 
@@ -332,14 +338,21 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
     Q_ASSERT(windowfunction.count() == points);
     if (windowfunction.count() != points) return;
 
-    QMemArray<complex> input(points);
-    Q_ASSERT(input.size() == points);
-    if (input.size() < points) return;
+    QMemArray<double> input(2*points);
+    Q_ASSERT(input.size() == 2*points);
+    if (input.size() < 2*points) return;
 
     // initialize the table for fft
-    gsl_fft_complex_wavetable table;
-    gsl_fft_complex_wavetable_alloc(points, &table);
-    gsl_fft_complex_init(points, &table);
+    wavetable = gsl_fft_complex_wavetable_alloc(points);
+    Q_ASSERT(wavetable);
+    if (!wavetable) return;
+
+    workspace = gsl_fft_complex_workspace_alloc(points);
+    Q_ASSERT(workspace);
+    if (!workspace) {
+	gsl_fft_complex_wavetable_free(wavetable);
+	return;
+    }
 
     // copy signal data into complex array
     for (unsigned int j = 0; j < points; j++) {
@@ -356,12 +369,13 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
 	    }
 	    value /= (double)(1<<23) * (double)count;
 	}
-	input[j].real = windowfunction[j] * value;
-	input[j].imag = 0;
+	input[j+j + 0] = windowfunction[j] * value;
+	input[j+j + 1] = 0;
     }
 
     // calculate the fft
-    gsl_fft_complex_forward(input.data(), points, &table);
+    gsl_fft_complex_forward(input.data(), 1, points,
+                            wavetable, workspace);
 
     double ima;
     double rea;
@@ -369,10 +383,10 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
 //    for (int k = 0; k < points/2; k++) {
 //	rea = data[k].real;
 //	ima = data[k].imag;
-//	
+//
 //	//get amplitude
 //	rea = sqrt(rea * rea + ima * ima);
-//	
+//
 //	//and set maximum for display..
 //	if (rea > max) max = rea;
 //    }
@@ -382,19 +396,20 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
     // norm all values to [0...255] and use them as pixel value
     if (max != 0) {
 	for (unsigned int j = 0; j < points/2; j++) {
-	    rea = input[j].real;
-	    ima = input[j].imag;
+	    rea = input[j+j + 0];
+	    ima = input[j+j + 1];
 	    rea = sqrt(rea * rea + ima * ima) / max;
-	
+
 	    // get amplitude and scale to 1
 	    rea = 1 - ((1 - rea) * (1 - rea));
-	
+
 	    output[j] = 0xFE - (int)(rea * 0xFE );
 	}
     }
 
     // free the intermediate array used for fft
-    gsl_fft_complex_wavetable_free(&table);
+    gsl_fft_complex_wavetable_free(wavetable);
+    gsl_fft_complex_workspace_free(workspace);
 }
 
 //***************************************************************************
